@@ -2,9 +2,11 @@
 from .testrail_api_reporter.engines.at_coverage_reporter import ATCoverageReporter
 from .testrail_api_reporter.engines.results_reporter import TestRailResultsReporter
 from .testrail_api_reporter.engines.plotly_reporter import PlotlyReporter
+from .testrail_api_reporter.engines.case_backup import TCBackup
 # Publishers
 from .testrail_api_reporter.publishers.confluence_sender import ConfluenceSender
 from .testrail_api_reporter.publishers.email_sender import EmailSender
 from .testrail_api_reporter.publishers.slack_sender import SlackSender
+from .testrail_api_reporter.publishers.gdrive_uploader import GoogleDriveUploader
 # Utils
-from .testrail_api_reporter.utils.reporter_utils import upload_image
+from .testrail_api_reporter.utils.reporter_utils import upload_image, zip_file, delete_file
